@@ -1,7 +1,7 @@
 __docformat__ = "restructuredtext en"
 from time import time, clock
 from numpy import asfarray, nan, ones, all, atleast_1d, any, isnan, \
-array_equal, asscalar, asarray, where, ndarray, isscalar, matrix, seterr, isinf
+array_equal, asscalar, asarray, ndarray, isscalar, matrix, seterr, isinf #where
 from setDefaultIterFuncs import stopcase,  SMALL_DELTA_X,  SMALL_DELTA_F, IS_MAX_ITER_REACHED
 from check import check
 from oologfcn import OpenOptException
@@ -15,6 +15,8 @@ from openopt.kernel.ooMisc import isSolved
 
 #from baseProblem import ProbDefaults
 from nonOptMisc import getSolverFromStringName, EmptyClass
+# for PyPy
+from openopt.kernel.nonOptMisc import where
 
 try:
     import setproctitle
@@ -323,7 +325,10 @@ def runProbSolver(p_, solver_str_or_instance=None, *args, **kwargs):
 
     # Solving finished
     if hasattr(p, '_bestPoint') and not any(isnan(p._bestPoint.x)) and p.probType != 'ODE':
-        p.iterfcn(p._bestPoint)
+        try:
+            p.iterfcn(p._bestPoint)
+        except isSolved:
+            pass
     if p.probType != 'EIG':
         if not hasattr(p, 'xf') and not hasattr(p, 'xk'): p.xf = p.xk = ones(p.n)*nan
         if hasattr(p, 'xf') and (not hasattr(p, 'xk') or array_equal(p.xk, p.x0)): p.xk = p.xf
